==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/WebChatChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.WebChatChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Web Chat channel.
 * @property sites The list of Web Chat sites
 */
public data class WebChatChannelPropertiesArgs(
    public val sites: Output<List<WebChatSiteArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.WebChatChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.WebChatChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.WebChatChannelPropertiesArgs.builder()
            .sites(
                sites?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [WebChatChannelPropertiesArgs].
 */
@PulumiTagMarker
public class WebChatChannelPropertiesArgsBuilder internal constructor() {
    private var sites: Output<List<WebChatSiteArgs>>? = null

    /**
     * @param value The list of Web Chat sites
     */
    @JvmName("lrrnyjbsjddncuff")
    public suspend fun sites(`value`: Output<List<WebChatSiteArgs>>) {
        this.sites = value
    }

    @JvmName("upmjcdnistqansif")
    public suspend fun sites(vararg values: Output<WebChatSiteArgs>) {
        this.sites = Output.all(values.asList())
    }

    /**
     * @param values The list of Web Chat sites
     */
    @JvmName("hwewpmymyngbewce")
    public suspend fun sites(values: List<Output<WebChatSiteArgs>>) {
        this.sites = Output.all(values)
    }

    /**
     * @param value The list of Web Chat sites
     */
    @JvmName("ifnmsmupvcirxtqa")
    public suspend fun sites(`value`: List<WebChatSiteArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sites = mapped
    }

    /**
     * @param argument The list of Web Chat sites
     */
    @JvmName("prouwswuclinkxyb")
    public suspend fun sites(argument: List<suspend WebChatSiteArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { WebChatSiteArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.sites = mapped
    }

    /**
     * @param argument The list of Web Chat sites
     */
    @JvmName("iuouiifonbrmnuik")
    public suspend fun sites(vararg argument: suspend WebChatSiteArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { WebChatSiteArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.sites = mapped
    }

    /**
     * @param argument The list of Web Chat sites
     */
    @JvmName("sssognrwjhwlmmlm")
    public suspend fun sites(argument: suspend WebChatSiteArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(WebChatSiteArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sites = mapped
    }

    /**
     * @param values The list of Web Chat sites
     */
    @JvmName("gottsfhgftfeuaku")
    public suspend fun sites(vararg values: WebChatSiteArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sites = mapped
    }

    internal fun build(): WebChatChannelPropertiesArgs = WebChatChannelPropertiesArgs(
        sites = sites,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/botservice/kotlin/inputs/WebChatChannelPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.botservice.kotlin.inputs

import com.pulumi.azurenative.botservice.inputs.WebChatChannelPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The parameters to provide for the Web Chat channel.
 * @property sites The list of Web Chat sites
 */
public data class WebChatChannelPropertiesArgs(
    public val sites: Output<List<WebChatSiteArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.botservice.inputs.WebChatChannelPropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.botservice.inputs.WebChatChannelPropertiesArgs =
        com.pulumi.azurenative.botservice.inputs.WebChatChannelPropertiesArgs.builder()
            .sites(
                sites?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [WebChatChannelPropertiesArgs].
 */
@PulumiTagMarker
public class WebChatChannelPropertiesArgsBuilder internal constructor() {
    private var sites: Output<List<WebChatSiteArgs>>? = null

    /**
     * @param value The list of Web Chat sites
     */
    @JvmName("mpestwetnlyprnje")
    public suspend fun sites(`value`: Output<List<WebChatSiteArgs>>) {
        this.sites = value
    }

    @JvmName("wocbjigdexssnytg")
    public suspend fun sites(vararg values: Output<WebChatSiteArgs>) {
        this.sites = Output.all(values.asList())
    }

    /**
     * @param values The list of Web Chat sites
     */
    @JvmName("ihlnfwrqlpvfmfnl")
    public suspend fun sites(values: List<Output<WebChatSiteArgs>>) {
        this.sites = Output.all(values)
    }

    /**
     * @param value The list of Web Chat sites
     */
    @JvmName("kmqpgxyqtnmkvpdn")
    public suspend fun sites(`value`: List<WebChatSiteArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sites = mapped
    }

    /**
     * @param argument The list of Web Chat sites
     */
    @JvmName("ppghmvijpjnegccq")
    public suspend fun sites(argument: List<suspend WebChatSiteArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map { WebChatSiteArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.sites = mapped
    }

    /**
     * @param argument The list of Web Chat sites
     */
    @JvmName("ypdkueaavxknambl")
    public suspend fun sites(vararg argument: suspend WebChatSiteArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map { WebChatSiteArgsBuilder().applySuspend { it() }.build() }
        val mapped = of(toBeMapped)
        this.sites = mapped
    }

    /**
     * @param argument The list of Web Chat sites
     */
    @JvmName("tdgijrsrowkxywnv")
    public suspend fun sites(argument: suspend WebChatSiteArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(WebChatSiteArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.sites = mapped
    }

    /**
     * @param values The list of Web Chat sites
     */
    @JvmName("cygfdcsecoxidrbb")
    public suspend fun sites(vararg values: WebChatSiteArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sites = mapped
    }

    internal fun build(): WebChatChannelPropertiesArgs = WebChatChannelPropertiesArgs(
        sites = sites,
    )
}
